@@ -6,7 +6,7 @@ import scipy
 import flammkuchen
 import numpy as np
 from . import utils, data, models, event_utils, segment_utils, annot
-from typing import List, Optional, Dict
+from typing import List, Optional, Dict, Any
 import glob
 
 
@@ -161,15 +161,15 @@ def predict_segments(class_probabilities: np.array,
 
 
 def predict_events(class_probabilities, samplerate: float = 1.0,
-                   event_dims: int = None, event_names: List[str] = None,
-                   event_thres: float = 0.5, events_offset: float = 0, event_dist: float=100,
-                   event_dist_min: float = 0, event_dist_max: float = np.inf):
+                   event_dims: List[int] = None, event_names: List[str] = None,
+                   event_thres: float = 0.5, events_offset: float = 0.0, event_dist: float = 100.0,
+                   event_dist_min: float = 0.0, event_dist_max: float = np.inf):
     """[summary]
 
     Args:
         class_probabilities ([type]): [samples, classes][description]
         samplerate (float, optional): Hz
-        event_dims ([type], optional): [description]. Defaults to range(nb_classes).
+        event_dims (List[int], optional): [description]. Defaults to np.arange(1, nb_classes) (excludes noise-class at index 0).
         event_names ([type], optional): [description]. Defaults to event_dims.
         event_thres (float, optional): [description]. Defaults to 0.5.
         events_offset (float, optional): . Defaults to 0 seconds.
@@ -185,13 +185,13 @@ def predict_events(class_probabilities, samplerate: float = 1.0,
     """
     if event_dims is None:
         nb_classes = class_probabilities.shape[1]
-        event_dims = range(nb_classes)
+        event_dims = np.arange(1, nb_classes).astype(np.uintp)
 
     if event_names is None:
-        event_names = event_dims
+        event_names = [str(dim) for dim in event_dims]
 
     if event_dist_max is None:
-        event_dist_max = np.inf #class_probabilities.shape[0] + 1
+        event_dist_max = np.inf
 
     events = dict()
     if len(event_dims):
@@ -204,7 +204,7 @@ def predict_events(class_probabilities, samplerate: float = 1.0,
         events['sequence'] = []
 
         for event_dim, event_name in zip(event_dims, event_names):
-            event_indices, event_probabilities = event_utils.detect_events(class_probabilities[:, event_dim],
+            event_indices, event_probabilities = event_utils.detect_events(class_probabilities, index=event_dim,
                                                                            thres=event_thres, min_dist=event_dist * samplerate)
             events_seconds = event_indices.astype(np.float) / samplerate
             events_seconds += events_offset
@@ -219,7 +219,7 @@ def predict_events(class_probabilities, samplerate: float = 1.0,
     return events
 
 
-def predict_song(class_probabilities: np.ndarray, params: dict = None,
+def predict_song(class_probabilities: np.ndarray, params: dict[str, Any],
                  event_thres: float = 0.5, event_dist: float = 0.01,
                  event_dist_min: float = 0, event_dist_max: float = None,
                  segment_ref_onsets: Optional[List[float]] = None,
@@ -328,19 +328,27 @@ def predict(x: np.array, model_save_name: str = None, verbose: int = 1,
 
     if batch_size is not None:
         params['batch_size'] = batch_size
-
+    # breakpoint()
     if pad:
         # figure out length in multiples of batches
-        pad_len = params['batch_size'] * params['nb_hist']
+
+        batch_len = params['batch_size'] * params['nb_hist'] + params['nb_hist']
+        x_len_original = len(x)
+        pad_len = 0
+        if np.remainder(len(x), batch_len) > 0:
+            pad_len = batch_len - np.remainder(len(x), batch_len)
         # pad with end val to fill
         x = np.pad(x, ((0, pad_len), (0, 0)), mode='edge')
 
     class_probabilities = predict_probabililties(x, model, params, verbose, prepend_data_padding)
 
-    if pad: # set all song probs in padded section to zero to avoid out of bounds detections!
+    if pad:
+        # trim probs to original len of x
+        class_probabilities = class_probabilities[:x_len_original, :]
+        # set all song probs in padded section to zero to avoid out of bounds detections!
         # assumes that the non-song class is at index 0
-        class_probabilities[-pad_len:, 1:] = 0
-        class_probabilities[-pad_len:, 0] = 1
+        # class_probabilities[-pad_len:, 1:] = 0
+        # class_probabilities[-pad_len:, 0] = 1
 
     events, segments = predict_song(class_probabilities=class_probabilities, params=params,
                                     event_thres=event_thres, event_dist=event_dist,
