@@ -278,7 +278,7 @@ def train(*,
         elif fraction_data < 1.0:
             logger.info(f"Using {fraction_data:1.4f} of the training and validation data.")
 
-    if fraction_data is not None and not batch_level_subsampling and not sample_bounds_provided:  # train on a subset
+    if fraction_data is not None and not batch_level_subsampling and not sample_bounds_provided and fraction_data != 1.0:  # train on a subset
         min_nb_samples = nb_hist * (batch_size + 2)  # ensure the generator contains at least one full batch
         first_sample_train, last_sample_train = data.sub_range(d['train']['x'].shape[0],
                                                                fraction_data,
@@ -288,9 +288,6 @@ def train(*,
     elif sample_bounds_provided:
         logger.info("Using provided start/end samples:")
         logger.info(f"Train: {first_sample_train}:{last_sample_train}, Val: {first_sample_val}:{last_sample_val}.")
-    # else:
-    #     first_sample_train, last_sample_train = 0, None
-    #     first_sample_val, last_sample_val = 0, None
 
     # TODO clarify nb_channels, nb_freq semantics - always [nb_samples,..., nb_channels] -  nb_freq is ill-defined for 2D data
     params.update({
@@ -355,7 +352,7 @@ def train(*,
     if balance:
         from sklearn.utils import class_weight
         y_train = np.argmax(d['train']['y'], axis=1)
-        params['class_weights'] = class_weight.compute_class_weight('balanced', np.unique(y_train), y_train)
+        params['class_weights'] = class_weight.compute_class_weight('balanced', classes=np.unique(y_train), y=y_train)
         logger.info(f"Balancing classes: {params['class_weights']}")
 
     logger.info('building network')
@@ -365,7 +362,6 @@ def train(*,
         logger.exception(e)
         raise ValueError(f'Model name was {model_name} but only {list(models.model_dict)} allowed.')
 
-
     logger.info(model.summary())
     os.makedirs(os.path.abspath(save_dir), exist_ok=True)
     if save_name is None:
@@ -422,10 +418,10 @@ def train(*,
         logger.info(f'     min_len={best_min_len} seconds')
 
         params['post_opt'] = {
-            'gap_dur': float(best_gap_dur),
-            'min_len': float(best_min_len),
-            'score_train': float(scores['train']),
-            'score_val': float(scores['val']),
+            'gap_dur': best_gap_dur,
+            'min_len': best_min_len,
+            'score_train': scores['train'],
+            'score_val': scores['val'],
         }
 
         logger.info(f'   Updating params file "{save_name}_params.yaml" with the results.')
@@ -437,7 +433,6 @@ def train(*,
     logger.info('TESTING:')
     if len(d['test']['x']) < nb_hist:
         logger.info('   No test data - skipping final evaluation step.')
-        return
     else:
         logger.info(f'   Re-loading last best model from {checkpoint_save_name}.')
         model.load_weights(checkpoint_save_name)
