@@ -389,7 +389,7 @@ def train(*, data_dir: str, x_suffix: str = '', y_suffix: str = '',
         elif fraction_data < 1.0:
             logging.info(f"Using {fraction_data:1.4f} of the training and validation data.")
 
-    if fraction_data is not None and not batch_level_subsampling:  # train on a subset
+    if fraction_data is not None and not batch_level_subsampling and fraction_data != 1.0:  # train on a subset
         min_nb_samples = nb_hist * (batch_size + 2)  # ensure the generator contains at least one full batch
         first_sample_train, last_sample_train = data.sub_range(d['train']['x'].shape[0], fraction_data, min_nb_samples, seed=seed)
         first_sample_val, last_sample_val = data.sub_range(d['val']['x'].shape[0], fraction_data, min_nb_samples, seed=seed)
@@ -417,8 +417,8 @@ def train(*, data_dir: str, x_suffix: str = '', y_suffix: str = '',
         from sklearn.utils import class_weight
         y_train = np.argmax(d['train']['y'], axis=1)
         params['class_weights'] = class_weight.compute_class_weight('balanced',
-                                                        np.unique(y_train),
-                                                        y_train)
+                                                                    classes=np.unique(y_train),
+                                                                    y=y_train)
         logging.info(f"Balancing classes: {params['class_weights']}")
 
     logging.info('building network')
@@ -445,10 +445,10 @@ def train(*, data_dir: str, x_suffix: str = '', y_suffix: str = '',
         callbacks.append(TensorBoard(log_dir=save_name))
 
     if wandb_api_token and wandb_project:  # could also get those from env vars!
-            del params['wandb_api_token']
-            wandb = tracking.Wandb(wandb_project, wandb_api_token, wandb_entity, params)
-            if wandb:
-                callbacks.append(wandb.callback())
+        del params['wandb_api_token']
+        wandb = tracking.Wandb(wandb_project, wandb_api_token, wandb_entity, params)
+        if wandb:
+            callbacks.append(wandb.callback())
     else:
         wandb = None
 
@@ -482,7 +482,6 @@ def train(*, data_dir: str, x_suffix: str = '', y_suffix: str = '',
     # TEST
     if len(d['test']['x']) < nb_hist:
         logging.info('No test data - skipping final evaluation step.')
-        return
     else:
         logging.info('re-loading last best model')
         model, params = utils.load_model_and_params(params['save_name'])
